==========
Adaptivity
==========

The Adaptivity commands are used to define objects, perform analyses, and calculate new meshes for Arbitrary Lagrangian Eularian (ALE) adaptive smoothing (adaptive meshing) and varying topology adaptivity (adaptive remeshing).


Create adaptivity mesh control features
---------------------------------------

.. autoclass:: abaqus.Adaptivity.AdaptivityModel.AdaptivityModel
    :members:

    .. autoclasstoc::


Create adaptivity mesh state features
-------------------------------------

.. autoclass:: abaqus.Adaptivity.AdaptivityStep.AdaptivityStep
    :members:

    .. autoclasstoc::


Create features for AdaptivityIteration
---------------------------------------

.. autoclass:: abaqus.Adaptivity.AdaptivityIteration.AdaptivityIteration
    :members:

    .. autoclasstoc::


Object Features
---------------

AdaptiveMeshConstraint
~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Adaptivity.AdaptiveMeshConstraint.AdaptiveMeshConstraint
    :members:

    .. autoclasstoc::
    
AdaptiveMeshConstraintState
~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Adaptivity.AdaptiveMeshConstraintState.AdaptiveMeshConstraintState
    :members:

    .. autoclasstoc::
    

AdaptiveMeshControl
~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Adaptivity.AdaptiveMeshControl.AdaptiveMeshControl
    :members:

    .. autoclasstoc::

AdaptiveMeshDomain
~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Adaptivity.AdaptiveMeshDomain.AdaptiveMeshDomain
    :members:

    .. autoclasstoc::

AdaptivityProcess
~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Adaptivity.AdaptivityProcess.AdaptivityProcess
    :members:

    .. autoclasstoc::

DisplacementAdaptiveMeshConstraint
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Adaptivity.DisplacementAdaptiveMeshConstraint.DisplacementAdaptiveMeshConstraint
    :members:

    .. autoclasstoc::

DisplacementAdaptiveMeshConstraintState
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Adaptivity.DisplacementAdaptiveMeshConstraintState.DisplacementAdaptiveMeshConstraintState
    :members:

    .. autoclasstoc::

ErrorIndicatorResult
~~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Adaptivity.ErrorIndicatorResult.ErrorIndicatorResult
    :members:

    .. autoclasstoc::

RemeshingRule
~~~~~~~~~~~~~

.. autoclass:: abaqus.Adaptivity.RemeshingRule.RemeshingRule
    :members:

    .. autoclasstoc::

RuleResult
~~~~~~~~~~
    
.. autoclass:: abaqus.Adaptivity.RuleResult.RuleResult
    :members:

    .. autoclasstoc::

VelocityAdaptiveMeshConstraint
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Adaptivity.VelocityAdaptiveMeshConstraint.VelocityAdaptiveMeshConstraint
    :members:

    .. autoclasstoc::

VelocityAdaptiveMeshConstraintState
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Adaptivity.VelocityAdaptiveMeshConstraintState.VelocityAdaptiveMeshConstraintState
    :members:

    .. autoclasstoc::
